pub trait SliceRange<D>: DimRange<D>where
D: Dim,{ }👎Deprecated:
Use DimRange instead. See issue #1076 for more information.
A range with a size that may be known at compile-time.
This is merely a legacy trait alias to minimize breakage. Use the DimRange trait instead.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".